VapViewController class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
playAsset(String asset) → Future<Map>
playPath(String path) → Future<Map>
return: play error: {"status": "failure", "errorMsg": ""} play complete: {"status": "complete"}
stop() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited